==> nestjs-i18n-9.3.0.tgz: package/.docusaurus/routes.js <==
import React from 'react';
import ComponentCreator from '@docusaurus/ComponentCreator';

export default [
  {
    path: '/search',
    component: ComponentCreator('/search', 'c0c'),
    exact: true
  },
  {
    path: '/',
    component: ComponentCreator('/', 'b2b'),
    routes: [
      {
        path: '/',
        component: ComponentCreator('/', '98e'),
        exact: true,
        sidebar: "tutorialSidebar"
      },
      {
        path: '/concepts/i18n-context',
        component: ComponentCreator('/concepts/i18n-context', '6e2'),
        exact: true,
        sidebar: "tutorialSidebar"
      },
      {
        path: '/concepts/loader',
        component: ComponentCreator('/concepts/loader', '54b'),
        exact: true,
        sidebar: "tutorialSidebar"
      },
      {
        path: '/concepts/resolver',
        component: ComponentCreator('/concepts/resolver', 'f41'),
        exact: true,
        sidebar: "tutorialSidebar"
      },
      {
        path: '/guides/debugging',
        component: ComponentCreator('/guides/debugging', '22d'),
        exact: true,
        sidebar: "tutorialSidebar"
      },
      {
        path: '/guides/dto_validation/global-validation',
        component: ComponentCreator('/guides/dto_validation/global-validation', '120'),
        exact: true,
        sidebar: "tutorialSidebar"
      },
      {
        path: '/guides/dto_validation/manual-validation',
        component: ComponentCreator('/guides/dto_validation/manual-validation', '5c5'),
        exact: true,
        sidebar: "tutorialSidebar"
      },
      {
        path: '/guides/exception-filters',
        component: ComponentCreator('/guides/exception-filters', '7db'),
        exact: true,
        sidebar: "tutorialSidebar"
      },
      {
        path: '/guides/fallback-languages',
        component: ComponentCreator('/guides/fallback-languages', '351'),
        exact: true,
        sidebar: "tutorialSidebar"
      },
      {
        path: '/guides/formatting',
        component: ComponentCreator('/guides/formatting', '2ee'),
        exact: true,
        sidebar: "tutorialSidebar"
      },
      {
        path: '/guides/graphql',
        component: ComponentCreator('/guides/graphql', '2d4'),
        exact: true,
        sidebar: "tutorialSidebar"
      },
      {
        path: '/guides/grpc',
        component: ComponentCreator('/guides/grpc', 'b00'),
        exact: true,
        sidebar: "tutorialSidebar"
      },
      {
        path: '/guides/guard',
        component: ComponentCreator('/guides/guard', '05a'),
        exact: true,
        sidebar: "tutorialSidebar"
      },
      {
        path: '/guides/mailer',
        component: ComponentCreator('/guides/mailer', '0ea'),
        exact: true,
        sidebar: "tutorialSidebar"
      },
      {
        path: '/guides/nested',
        component: ComponentCreator('/guides/nested', '8e9'),
        exact: true,
        sidebar: "tutorialSidebar"
      },
      {
        path: '/guides/plurals',
        component: ComponentCreator('/guides/plurals', '3ba'),
        exact: true,
        sidebar: "tutorialSidebar"
      },
      {
        path: '/guides/view_engines/ejs',
        component: ComponentCreator('/guides/view_engines/ejs', 'd98'),
        exact: true,
        sidebar: "tutorialSidebar"
      },
      {
        path: '/guides/view_engines/handlebars',
        component: ComponentCreator('/guides/view_engines/handlebars', '666'),
        exact: true,
        sidebar: "tutorialSidebar"
      },
      {
        path: '/guides/view_engines/pug',
        component: ComponentCreator('/guides/view_engines/pug', '047'),
        exact: true,
        sidebar: "tutorialSidebar"
      },
      {
        path: '/quick-start',
        component: ComponentCreator('/quick-start', '2a3'),
        exact: true,
        sidebar: "tutorialSidebar"
      }
    ]
  },
  {
    path: '*',
    component: ComponentCreator('*'),
  },
];

==> nestjs-i18n-10.0.0.tgz: package/.docusaurus/routes.js <==
import React from 'react';
import ComponentCreator from '@docusaurus/ComponentCreator';

export default [
  {
    path: '/__docusaurus/debug',
    component: ComponentCreator('/__docusaurus/debug', 'ae4'),
    exact: true
  },
  {
    path: '/__docusaurus/debug/config',
    component: ComponentCreator('/__docusaurus/debug/config', 'fa2'),
    exact: true
  },
  {
    path: '/__docusaurus/debug/content',
    component: ComponentCreator('/__docusaurus/debug/content', '9c2'),
    exact: true
  },
  {
    path: '/__docusaurus/debug/globalData',
    component: ComponentCreator('/__docusaurus/debug/globalData', '965'),
    exact: true
  },
  {
    path: '/__docusaurus/debug/metadata',
    component: ComponentCreator('/__docusaurus/debug/metadata', '725'),
    exact: true
  },
  {
    path: '/__docusaurus/debug/registry',
    component: ComponentCreator('/__docusaurus/debug/registry', 'ef6'),
    exact: true
  },
  {
    path: '/__docusaurus/debug/routes',
    component: ComponentCreator('/__docusaurus/debug/routes', '411'),
    exact: true
  },
  {
    path: '/search',
    component: ComponentCreator('/search', 'c0c'),
    exact: true
  },
  {
    path: '/',
    component: ComponentCreator('/', 'ebf'),
    routes: [
      {
        path: '/',
        component: ComponentCreator('/', '98e'),
        exact: true,
        sidebar: "tutorialSidebar"
      },
      {
        path: '/concepts/i18n-context',
        component: ComponentCreator('/concepts/i18n-context', '6e2'),
        exact: true,
        sidebar: "tutorialSidebar"
      },
      {
        path: '/concepts/loader',
        component: ComponentCreator('/concepts/loader', '54b'),
        exact: true,
        sidebar: "tutorialSidebar"
      },
      {
        path: '/concepts/resolver',
        component: ComponentCreator('/concepts/resolver', 'f41'),
        exact: true,
        sidebar: "tutorialSidebar"
      },
      {
        path: '/guides/array',
        component: ComponentCreator('/guides/array', '55b'),
        exact: true,
        sidebar: "tutorialSidebar"
      },
      {
        path: '/guides/debugging',
        component: ComponentCreator('/guides/debugging', '22d'),
        exact: true,
        sidebar: "tutorialSidebar"
      },
      {
        path: '/guides/dto_validation/global-validation',
        component: ComponentCreator('/guides/dto_validation/global-validation', '120'),
        exact: true,
        sidebar: "tutorialSidebar"
      },
      {
        path: '/guides/dto_validation/manual-validation',
        component: ComponentCreator('/guides/dto_validation/manual-validation', '5c5'),
        exact: true,
        sidebar: "tutorialSidebar"
      },
      {
        path: '/guides/exception-filters',
        component: ComponentCreator('/guides/exception-filters', '7db'),
        exact: true,
        sidebar: "tutorialSidebar"
      },
      {
        path: '/guides/fallback-languages',
        component: ComponentCreator('/guides/fallback-languages', '351'),
        exact: true,
        sidebar: "tutorialSidebar"
      },
      {
        path: '/guides/formatting',
        component: ComponentCreator('/guides/formatting', '2ee'),
        exact: true,
        sidebar: "tutorialSidebar"
      },
      {
        path: '/guides/graphql',
        component: ComponentCreator('/guides/graphql', '2d4'),
        exact: true,
        sidebar: "tutorialSidebar"
      },
      {
        path: '/guides/grpc',
        component: ComponentCreator('/guides/grpc', 'b00'),
        exact: true,
        sidebar: "tutorialSidebar"
      },
      {
        path: '/guides/guard',
        component: ComponentCreator('/guides/guard', '05a'),
        exact: true,
        sidebar: "tutorialSidebar"
      },
      {
        path: '/guides/mailer',
        component: ComponentCreator('/guides/mailer', '0ea'),
        exact: true,
        sidebar: "tutorialSidebar"
      },
      {
        path: '/guides/nested',
        component: ComponentCreator('/guides/nested', '8e9'),
        exact: true,
        sidebar: "tutorialSidebar"
      },
      {
        path: '/guides/plurals',
        component: ComponentCreator('/guides/plurals', '3ba'),
        exact: true,
        sidebar: "tutorialSidebar"
      },
      {
        path: '/guides/view_engines/ejs',
        component: ComponentCreator('/guides/view_engines/ejs', 'd98'),
        exact: true,
        sidebar: "tutorialSidebar"
      },
      {
        path: '/guides/view_engines/handlebars',
        component: ComponentCreator('/guides/view_engines/handlebars', '666'),
        exact: true,
        sidebar: "tutorialSidebar"
      },
      {
        path: '/guides/view_engines/pug',
        component: ComponentCreator('/guides/view_engines/pug', '047'),
        exact: true,
        sidebar: "tutorialSidebar"
      },
      {
        path: '/quick-start',
        component: ComponentCreator('/quick-start', '2a3'),
        exact: true,
        sidebar: "tutorialSidebar"
      }
    ]
  },
  {
    path: '*',
    component: ComponentCreator('*'),
  },
];
